@@ -11,7 +11,10 @@ import publication
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "monocdk-experiment", "1.60.0", __name__[0:-6], "monocdk-experiment@1.60.0.jsii.tgz"
+    "monocdk-experiment",
+    "1.61.0",
+    __name__[0:-6],
+    "monocdk-experiment@1.61.0.jsii.tgz",
 )
 
 __all__ = [
