@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    TreeInspector as _TreeInspector_154f5999,
     IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -155,27 +155,10 @@ class CfnTable(
         id: str,
         *,
         keyspace_name: str,
-        partition_key_columns: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
-        ],
-        billing_mode: typing.Optional[
-            typing.Union["BillingModeProperty", _IResolvable_9ceae33e]
-        ] = None,
-        clustering_key_columns: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
-        regular_columns: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
-            ]
-        ] = None,
+        partition_key_columns: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]],
+        billing_mode: typing.Optional[typing.Union["BillingModeProperty", _IResolvable_9ceae33e]] = None,
+        clustering_key_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]] = None,
+        regular_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]] = None,
         table_name: typing.Optional[str] = None,
     ) -> None:
         """Create a new ``AWS::Cassandra::Table``.
@@ -249,10 +232,7 @@ class CfnTable(
     @jsii.member(jsii_name="partitionKeyColumns")
     def partition_key_columns(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]:
         """``AWS::Cassandra::Table.PartitionKeyColumns``.
 
         see
@@ -263,10 +243,7 @@ class CfnTable(
     @partition_key_columns.setter
     def partition_key_columns(
         self,
-        value: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
-        ],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "partitionKeyColumns", value)
 
@@ -285,9 +262,7 @@ class CfnTable(
     @billing_mode.setter
     def billing_mode(
         self,
-        value: typing.Optional[
-            typing.Union["BillingModeProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["BillingModeProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "billingMode", value)
 
@@ -295,14 +270,7 @@ class CfnTable(
     @jsii.member(jsii_name="clusteringKeyColumns")
     def clustering_key_columns(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Cassandra::Table.ClusteringKeyColumns``.
 
         see
@@ -313,14 +281,7 @@ class CfnTable(
     @clustering_key_columns.setter
     def clustering_key_columns(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "clusteringKeyColumns", value)
 
@@ -328,12 +289,7 @@ class CfnTable(
     @jsii.member(jsii_name="regularColumns")
     def regular_columns(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Cassandra::Table.RegularColumns``.
 
         see
@@ -344,12 +300,7 @@ class CfnTable(
     @regular_columns.setter
     def regular_columns(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ColumnProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "regularColumns", value)
 
@@ -380,11 +331,7 @@ class CfnTable(
             self,
             *,
             mode: str,
-            provisioned_throughput: typing.Optional[
-                typing.Union[
-                    "CfnTable.ProvisionedThroughputProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            provisioned_throughput: typing.Optional[typing.Union["CfnTable.ProvisionedThroughputProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param mode: ``CfnTable.BillingModeProperty.Mode``.
@@ -411,11 +358,7 @@ class CfnTable(
         @builtins.property
         def provisioned_throughput(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnTable.ProvisionedThroughputProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnTable.ProvisionedThroughputProperty", _IResolvable_9ceae33e]]:
             """``CfnTable.BillingModeProperty.ProvisionedThroughput``.
 
             see
@@ -548,7 +491,10 @@ class CfnTable(
     )
     class ProvisionedThroughputProperty:
         def __init__(
-            self, *, read_capacity_units: jsii.Number, write_capacity_units: jsii.Number
+            self,
+            *,
+            read_capacity_units: jsii.Number,
+            write_capacity_units: jsii.Number,
         ) -> None:
             """
             :param read_capacity_units: ``CfnTable.ProvisionedThroughputProperty.ReadCapacityUnits``.
@@ -609,31 +555,10 @@ class CfnTableProps:
         self,
         *,
         keyspace_name: str,
-        partition_key_columns: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]],
-        ],
-        billing_mode: typing.Optional[
-            typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]
-        ] = None,
-        clustering_key_columns: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
-        regular_columns: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        partition_key_columns: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]],
+        billing_mode: typing.Optional[typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]] = None,
+        clustering_key_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]] = None,
+        regular_columns: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]] = None,
         table_name: typing.Optional[str] = None,
     ) -> None:
         """Properties for defining a ``AWS::Cassandra::Table``.
@@ -673,10 +598,7 @@ class CfnTableProps:
     @builtins.property
     def partition_key_columns(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]:
         """``AWS::Cassandra::Table.PartitionKeyColumns``.
 
         see
@@ -687,9 +609,7 @@ class CfnTableProps:
     @builtins.property
     def billing_mode(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnTable.BillingModeProperty", _IResolvable_9ceae33e]]:
         """``AWS::Cassandra::Table.BillingMode``.
 
         see
@@ -700,16 +620,7 @@ class CfnTableProps:
     @builtins.property
     def clustering_key_columns(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ClusteringKeyColumnProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Cassandra::Table.ClusteringKeyColumns``.
 
         see
@@ -720,12 +631,7 @@ class CfnTableProps:
     @builtins.property
     def regular_columns(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnTable.ColumnProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Cassandra::Table.RegularColumns``.
 
         see
