@@ -11,15 +11,15 @@ import publication
 from .._jsii import *
 
 from .. import (
-    Resource as _Resource_884d0774,
-    Construct as _Construct_f50a3f53,
     CfnResource as _CfnResource_7760e8e4,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
     IResource as _IResource_72f7ee7e,
+    Resource as _Resource_884d0774,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_iam import IRole as _IRole_e69bbae4
 from ..aws_route53 import IHostedZone as _IHostedZone_59ffab76
@@ -256,9 +256,7 @@ class CertificationValidationProps:
         self,
         *,
         hosted_zone: typing.Optional[_IHostedZone_59ffab76] = None,
-        hosted_zones: typing.Optional[
-            typing.Mapping[str, _IHostedZone_59ffab76]
-        ] = None,
+        hosted_zones: typing.Optional[typing.Mapping[str, _IHostedZone_59ffab76]] = None,
         method: typing.Optional["ValidationMethod"] = None,
         validation_domains: typing.Optional[typing.Mapping[str, str]] = None,
     ) -> None:
@@ -366,16 +364,7 @@ class CfnCertificate(
         domain_name: str,
         certificate_authority_arn: typing.Optional[str] = None,
         certificate_transparency_logging_preference: typing.Optional[str] = None,
-        domain_validation_options: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "DomainValidationOptionProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        domain_validation_options: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DomainValidationOptionProperty", _IResolvable_9ceae33e]]]] = None,
         subject_alternative_names: typing.Optional[typing.List[str]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
         validation_method: typing.Optional[str] = None,
@@ -493,14 +482,7 @@ class CfnCertificate(
     @jsii.member(jsii_name="domainValidationOptions")
     def domain_validation_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["DomainValidationOptionProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DomainValidationOptionProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::CertificateManager::Certificate.DomainValidationOptions``.
 
         see
@@ -511,16 +493,7 @@ class CfnCertificate(
     @domain_validation_options.setter
     def domain_validation_options(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "DomainValidationOptionProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DomainValidationOptionProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "domainValidationOptions", value)
 
@@ -646,17 +619,7 @@ class CfnCertificateProps:
         domain_name: str,
         certificate_authority_arn: typing.Optional[str] = None,
         certificate_transparency_logging_preference: typing.Optional[str] = None,
-        domain_validation_options: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnCertificate.DomainValidationOptionProperty",
-                        _IResolvable_9ceae33e,
-                    ]
-                ],
-            ]
-        ] = None,
+        domain_validation_options: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnCertificate.DomainValidationOptionProperty", _IResolvable_9ceae33e]]]] = None,
         subject_alternative_names: typing.Optional[typing.List[str]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
         validation_method: typing.Optional[str] = None,
@@ -680,9 +643,7 @@ class CfnCertificateProps:
         if certificate_authority_arn is not None:
             self._values["certificate_authority_arn"] = certificate_authority_arn
         if certificate_transparency_logging_preference is not None:
-            self._values[
-                "certificate_transparency_logging_preference"
-            ] = certificate_transparency_logging_preference
+            self._values["certificate_transparency_logging_preference"] = certificate_transparency_logging_preference
         if domain_validation_options is not None:
             self._values["domain_validation_options"] = domain_validation_options
         if subject_alternative_names is not None:
@@ -722,17 +683,7 @@ class CfnCertificateProps:
     @builtins.property
     def domain_validation_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnCertificate.DomainValidationOptionProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnCertificate.DomainValidationOptionProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::CertificateManager::Certificate.DomainValidationOptions``.
 
         see
