@@ -10,15 +10,15 @@ import publication
 
 from .._jsii import *
 
-from .. import Duration as _Duration_5170c158, Construct as _Construct_f50a3f53
+from .. import Construct as _Construct_f50a3f53, Duration as _Duration_5170c158
 from ..aws_cloudfront import (
-    OriginBase as _OriginBase_c136d438,
-    OriginProtocolPolicy as _OriginProtocolPolicy_d2d28ec7,
     CfnDistribution as _CfnDistribution_3a5e7b5c,
-    OriginProps as _OriginProps_3ddcc1c8,
     IOrigin as _IOrigin_ceac1980,
+    OriginBase as _OriginBase_c136d438,
     OriginBindConfig as _OriginBindConfig_86e63cf0,
     OriginBindOptions as _OriginBindOptions_5b2ffb69,
+    OriginProps as _OriginProps_3ddcc1c8,
+    OriginProtocolPolicy as _OriginProtocolPolicy_d2d28ec7,
 )
 from ..aws_elasticloadbalancingv2 import ILoadBalancerV2 as _ILoadBalancerV2_3b69d63d
 from ..aws_s3 import IBucket as _IBucket_25bad983
@@ -80,7 +80,7 @@ class HttpOrigin(
 
     @jsii.member(jsii_name="renderCustomOriginConfig")
     def _render_custom_origin_config(
-        self,
+        self
     ) -> typing.Optional[_CfnDistribution_3a5e7b5c.CustomOriginConfigProperty]:
         """
         stability
