@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
+    IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
     TreeInspector as _TreeInspector_154f5999,
-    IInspectable as _IInspectable_051e6ed8,
 )
 
 
@@ -295,9 +295,7 @@ class CfnMicrosoftADProps:
         *,
         name: str,
         password: str,
-        vpc_settings: typing.Union[
-            "CfnMicrosoftAD.VpcSettingsProperty", _IResolvable_9ceae33e
-        ],
+        vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", _IResolvable_9ceae33e],
         create_alias: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         edition: typing.Optional[str] = None,
         enable_sso: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
@@ -704,9 +702,7 @@ class CfnSimpleADProps:
         name: str,
         password: str,
         size: str,
-        vpc_settings: typing.Union[
-            "CfnSimpleAD.VpcSettingsProperty", _IResolvable_9ceae33e
-        ],
+        vpc_settings: typing.Union["CfnSimpleAD.VpcSettingsProperty", _IResolvable_9ceae33e],
         create_alias: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         description: typing.Optional[str] = None,
         enable_sso: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
