@@ -12,30 +12,30 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
-    IInspectable as _IInspectable_051e6ed8,
-    IResource as _IResource_72f7ee7e,
+    Construct as _Construct_f50a3f53,
     Duration as _Duration_5170c158,
-    RemovalPolicy as _RemovalPolicy_5986e9f3,
     IConstruct as _IConstruct_db0cc7e3,
+    IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    IResource as _IResource_72f7ee7e,
+    RemovalPolicy as _RemovalPolicy_5986e9f3,
     Resource as _Resource_884d0774,
     ResourceProps as _ResourceProps_92be6f66,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_events import (
-    Rule as _Rule_c38e0b39,
-    OnEventOptions as _OnEventOptions_926fbcf9,
     EventPattern as _EventPattern_8aa7b781,
     IRuleTarget as _IRuleTarget_41800a77,
+    OnEventOptions as _OnEventOptions_926fbcf9,
+    Rule as _Rule_c38e0b39,
 )
 from ..aws_iam import (
     AddToResourcePolicyResult as _AddToResourcePolicyResult_d2a345d1,
-    PolicyStatement as _PolicyStatement_f75dc775,
     Grant as _Grant_96af6d2d,
     IGrantable as _IGrantable_0fcfc53a,
+    PolicyStatement as _PolicyStatement_f75dc775,
 )
 
 
@@ -58,9 +58,7 @@ class CfnRepository(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        lifecycle_policy: typing.Optional[
-            typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]
-        ] = None,
+        lifecycle_policy: typing.Optional[typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]] = None,
         repository_name: typing.Optional[str] = None,
         repository_policy_text: typing.Any = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
@@ -151,9 +149,7 @@ class CfnRepository(
     @jsii.member(jsii_name="lifecyclePolicy")
     def lifecycle_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]]:
         """``AWS::ECR::Repository.LifecyclePolicy``.
 
         see
@@ -164,9 +160,7 @@ class CfnRepository(
     @lifecycle_policy.setter
     def lifecycle_policy(
         self,
-        value: typing.Optional[
-            typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["LifecyclePolicyProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "lifecyclePolicy", value)
 
@@ -256,9 +250,7 @@ class CfnRepositoryProps:
     def __init__(
         self,
         *,
-        lifecycle_policy: typing.Optional[
-            typing.Union["CfnRepository.LifecyclePolicyProperty", _IResolvable_9ceae33e]
-        ] = None,
+        lifecycle_policy: typing.Optional[typing.Union["CfnRepository.LifecyclePolicyProperty", _IResolvable_9ceae33e]] = None,
         repository_name: typing.Optional[str] = None,
         repository_policy_text: typing.Any = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
@@ -286,9 +278,7 @@ class CfnRepositoryProps:
     @builtins.property
     def lifecycle_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnRepository.LifecyclePolicyProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnRepository.LifecyclePolicyProperty", _IResolvable_9ceae33e]]:
         """``AWS::ECR::Repository.LifecyclePolicy``.
 
         see
@@ -1751,9 +1741,7 @@ class Repository(
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(
-            cls, "arnForLocalRepository", [repository_name, scope, account]
-        )
+        return jsii.sinvoke(cls, "arnForLocalRepository", [repository_name, scope, account])
 
     @jsii.member(jsii_name="fromRepositoryArn")
     @builtins.classmethod
