@@ -40,12 +40,8 @@ class AuthenticateCognitoAction(
         user_pool: _IUserPool_e9547b0f,
         user_pool_client: _IUserPoolClient_fd99c9a8,
         user_pool_domain: _IUserPoolDomain_a6fbdcfa,
-        authentication_request_extra_params: typing.Optional[
-            typing.Mapping[str, str]
-        ] = None,
-        on_unauthenticated_request: typing.Optional[
-            _UnauthenticatedAction_217b7279
-        ] = None,
+        authentication_request_extra_params: typing.Optional[typing.Mapping[str, str]] = None,
+        on_unauthenticated_request: typing.Optional[_UnauthenticatedAction_217b7279] = None,
         scope: typing.Optional[str] = None,
         session_cookie_name: typing.Optional[str] = None,
         session_timeout: typing.Optional[_Duration_5170c158] = None,
@@ -103,12 +99,8 @@ class AuthenticateCognitoActionProps:
         user_pool: _IUserPool_e9547b0f,
         user_pool_client: _IUserPoolClient_fd99c9a8,
         user_pool_domain: _IUserPoolDomain_a6fbdcfa,
-        authentication_request_extra_params: typing.Optional[
-            typing.Mapping[str, str]
-        ] = None,
-        on_unauthenticated_request: typing.Optional[
-            _UnauthenticatedAction_217b7279
-        ] = None,
+        authentication_request_extra_params: typing.Optional[typing.Mapping[str, str]] = None,
+        on_unauthenticated_request: typing.Optional[_UnauthenticatedAction_217b7279] = None,
         scope: typing.Optional[str] = None,
         session_cookie_name: typing.Optional[str] = None,
         session_timeout: typing.Optional[_Duration_5170c158] = None,
@@ -135,9 +127,7 @@ class AuthenticateCognitoActionProps:
             "user_pool_domain": user_pool_domain,
         }
         if authentication_request_extra_params is not None:
-            self._values[
-                "authentication_request_extra_params"
-            ] = authentication_request_extra_params
+            self._values["authentication_request_extra_params"] = authentication_request_extra_params
         if on_unauthenticated_request is not None:
             self._values["on_unauthenticated_request"] = on_unauthenticated_request
         if scope is not None:
