@@ -11,17 +11,19 @@ import publication
 from .._jsii import *
 
 from .. import (
-    Resource as _Resource_884d0774,
-    Construct as _Construct_f50a3f53,
     CfnResource as _CfnResource_7760e8e4,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
     IResource as _IResource_72f7ee7e,
+    Resource as _Resource_884d0774,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
+)
+from ..aws_ec2 import (
+    ISecurityGroup as _ISecurityGroup_d72ab8e8, IVpc as _IVpc_3795853f
 )
-from ..aws_ec2 import ISecurityGroup as _ISecurityGroup_d72ab8e8, IVpc as _IVpc_3795853f
 
 
 @jsii.data_type(
@@ -460,14 +462,7 @@ class CfnEndpointGroup(
         *,
         endpoint_group_region: str,
         listener_arn: str,
-        endpoint_configurations: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["EndpointConfigurationProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        endpoint_configurations: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EndpointConfigurationProperty", _IResolvable_9ceae33e]]]] = None,
         health_check_interval_seconds: typing.Optional[jsii.Number] = None,
         health_check_path: typing.Optional[str] = None,
         health_check_port: typing.Optional[jsii.Number] = None,
@@ -575,14 +570,7 @@ class CfnEndpointGroup(
     @jsii.member(jsii_name="endpointConfigurations")
     def endpoint_configurations(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["EndpointConfigurationProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EndpointConfigurationProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::GlobalAccelerator::EndpointGroup.EndpointConfigurations``.
 
         see
@@ -593,14 +581,7 @@ class CfnEndpointGroup(
     @endpoint_configurations.setter
     def endpoint_configurations(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["EndpointConfigurationProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["EndpointConfigurationProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "endpointConfigurations", value)
 
@@ -704,9 +685,7 @@ class CfnEndpointGroup(
             self,
             *,
             endpoint_id: str,
-            client_ip_preservation_enabled: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            client_ip_preservation_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             weight: typing.Optional[jsii.Number] = None,
         ) -> None:
             """
@@ -721,9 +700,7 @@ class CfnEndpointGroup(
                 "endpoint_id": endpoint_id,
             }
             if client_ip_preservation_enabled is not None:
-                self._values[
-                    "client_ip_preservation_enabled"
-                ] = client_ip_preservation_enabled
+                self._values["client_ip_preservation_enabled"] = client_ip_preservation_enabled
             if weight is not None:
                 self._values["weight"] = weight
 
@@ -789,17 +766,7 @@ class CfnEndpointGroupProps:
         *,
         endpoint_group_region: str,
         listener_arn: str,
-        endpoint_configurations: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnEndpointGroup.EndpointConfigurationProperty",
-                        _IResolvable_9ceae33e,
-                    ]
-                ],
-            ]
-        ] = None,
+        endpoint_configurations: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEndpointGroup.EndpointConfigurationProperty", _IResolvable_9ceae33e]]]] = None,
         health_check_interval_seconds: typing.Optional[jsii.Number] = None,
         health_check_path: typing.Optional[str] = None,
         health_check_port: typing.Optional[jsii.Number] = None,
@@ -829,9 +796,7 @@ class CfnEndpointGroupProps:
         if endpoint_configurations is not None:
             self._values["endpoint_configurations"] = endpoint_configurations
         if health_check_interval_seconds is not None:
-            self._values[
-                "health_check_interval_seconds"
-            ] = health_check_interval_seconds
+            self._values["health_check_interval_seconds"] = health_check_interval_seconds
         if health_check_path is not None:
             self._values["health_check_path"] = health_check_path
         if health_check_port is not None:
@@ -864,17 +829,7 @@ class CfnEndpointGroupProps:
     @builtins.property
     def endpoint_configurations(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnEndpointGroup.EndpointConfigurationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEndpointGroup.EndpointConfigurationProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::GlobalAccelerator::EndpointGroup.EndpointConfigurations``.
 
         see
@@ -968,10 +923,7 @@ class CfnListener(
         id: str,
         *,
         accelerator_arn: str,
-        port_ranges: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["PortRangeProperty", _IResolvable_9ceae33e]],
-        ],
+        port_ranges: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PortRangeProperty", _IResolvable_9ceae33e]]],
         protocol: str,
         client_affinity: typing.Optional[str] = None,
     ) -> None:
@@ -1051,10 +1003,7 @@ class CfnListener(
     @jsii.member(jsii_name="portRanges")
     def port_ranges(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union["PortRangeProperty", _IResolvable_9ceae33e]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PortRangeProperty", _IResolvable_9ceae33e]]]:
         """``AWS::GlobalAccelerator::Listener.PortRanges``.
 
         see
@@ -1065,10 +1014,7 @@ class CfnListener(
     @port_ranges.setter
     def port_ranges(
         self,
-        value: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["PortRangeProperty", _IResolvable_9ceae33e]],
-        ],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PortRangeProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "portRanges", value)
 
@@ -1164,12 +1110,7 @@ class CfnListenerProps:
         self,
         *,
         accelerator_arn: str,
-        port_ranges: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnListener.PortRangeProperty", _IResolvable_9ceae33e]
-            ],
-        ],
+        port_ranges: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnListener.PortRangeProperty", _IResolvable_9ceae33e]]],
         protocol: str,
         client_affinity: typing.Optional[str] = None,
     ) -> None:
@@ -1203,12 +1144,7 @@ class CfnListenerProps:
     @builtins.property
     def port_ranges(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[
-            typing.Union["CfnListener.PortRangeProperty", _IResolvable_9ceae33e]
-        ],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnListener.PortRangeProperty", _IResolvable_9ceae33e]]]:
         """``AWS::GlobalAccelerator::Listener.PortRanges``.
 
         see
@@ -1417,7 +1353,7 @@ class EndpointConfiguration(
 
     @jsii.member(jsii_name="renderEndpointConfiguration")
     def render_endpoint_configuration(
-        self,
+        self
     ) -> "CfnEndpointGroup.EndpointConfigurationProperty":
         """render the endpoint configuration for the endpoint group.
 
@@ -2173,7 +2109,12 @@ class Accelerator(
     @jsii.member(jsii_name="fromAcceleratorAttributes")
     @builtins.classmethod
     def from_accelerator_attributes(
-        cls, scope: _Construct_f50a3f53, id: str, *, accelerator_arn: str, dns_name: str
+        cls,
+        scope: _Construct_f50a3f53,
+        id: str,
+        *,
+        accelerator_arn: str,
+        dns_name: str,
     ) -> "IAccelerator":
         """import from attributes.
 
@@ -2263,9 +2204,7 @@ class EndpointGroup(
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(
-            cls, "fromEndpointGroupArn", [scope, id, endpoint_group_arn]
-        )
+        return jsii.sinvoke(cls, "fromEndpointGroupArn", [scope, id, endpoint_group_arn])
 
     @jsii.member(jsii_name="addEc2Instance")
     def add_ec2_instance(
