@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
+    IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
     TreeInspector as _TreeInspector_154f5999,
-    IInspectable as _IInspectable_051e6ed8,
 )
 
 
@@ -195,9 +195,7 @@ class CfnFilter(
         action: str,
         description: str,
         detector_id: str,
-        finding_criteria: typing.Union[
-            "FindingCriteriaProperty", _IResolvable_9ceae33e
-        ],
+        finding_criteria: typing.Union["FindingCriteriaProperty", _IResolvable_9ceae33e],
         name: str,
         rank: jsii.Number,
     ) -> None:
@@ -345,7 +343,13 @@ class CfnFilter(
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_guardduty.CfnFilter.ConditionProperty",
         jsii_struct_bases=[],
-        name_mapping={"eq": "eq", "gte": "gte", "lt": "lt", "lte": "lte", "neq": "neq"},
+        name_mapping={
+            "eq": "eq",
+            "gte": "gte",
+            "lt": "lt",
+            "lte": "lte",
+            "neq": "neq",
+        },
     )
     class ConditionProperty:
         def __init__(
@@ -445,9 +449,7 @@ class CfnFilter(
             self,
             *,
             criterion: typing.Any = None,
-            item_type: typing.Optional[
-                typing.Union["CfnFilter.ConditionProperty", _IResolvable_9ceae33e]
-            ] = None,
+            item_type: typing.Optional[typing.Union["CfnFilter.ConditionProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param criterion: ``CfnFilter.FindingCriteriaProperty.Criterion``.
@@ -474,9 +476,7 @@ class CfnFilter(
         @builtins.property
         def item_type(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnFilter.ConditionProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnFilter.ConditionProperty", _IResolvable_9ceae33e]]:
             """``CfnFilter.FindingCriteriaProperty.ItemType``.
 
             see
@@ -515,9 +515,7 @@ class CfnFilterProps:
         action: str,
         description: str,
         detector_id: str,
-        finding_criteria: typing.Union[
-            "CfnFilter.FindingCriteriaProperty", _IResolvable_9ceae33e
-        ],
+        finding_criteria: typing.Union["CfnFilter.FindingCriteriaProperty", _IResolvable_9ceae33e],
         name: str,
         rank: jsii.Number,
     ) -> None:
@@ -1060,9 +1058,7 @@ class CfnMember(
         detector_id: str,
         email: str,
         member_id: str,
-        disable_email_notification: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        disable_email_notification: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         message: typing.Optional[str] = None,
         status: typing.Optional[str] = None,
     ) -> None:
@@ -1227,9 +1223,7 @@ class CfnMemberProps:
         detector_id: str,
         email: str,
         member_id: str,
-        disable_email_notification: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        disable_email_notification: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         message: typing.Optional[str] = None,
         status: typing.Optional[str] = None,
     ) -> None:
