@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
+    IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
     TreeInspector as _TreeInspector_154f5999,
-    IInspectable as _IInspectable_051e6ed8,
 )
 
 
@@ -445,9 +445,7 @@ class CfnProject(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        placement_template: typing.Union[
-            "PlacementTemplateProperty", _IResolvable_9ceae33e
-        ],
+        placement_template: typing.Union["PlacementTemplateProperty", _IResolvable_9ceae33e],
         description: typing.Optional[str] = None,
         project_name: typing.Optional[str] = None,
     ) -> None:
@@ -632,17 +630,7 @@ class CfnProject(
             self,
             *,
             default_attributes: typing.Any = None,
-            device_templates: typing.Optional[
-                typing.Union[
-                    _IResolvable_9ceae33e,
-                    typing.Mapping[
-                        str,
-                        typing.Union[
-                            "CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e
-                        ],
-                    ],
-                ]
-            ] = None,
+            device_templates: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, typing.Union["CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e]]]] = None,
         ) -> None:
             """
             :param default_attributes: ``CfnProject.PlacementTemplateProperty.DefaultAttributes``.
@@ -669,17 +657,7 @@ class CfnProject(
         @builtins.property
         def device_templates(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.Mapping[
-                    str,
-                    typing.Union[
-                        "CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e
-                    ],
-                ],
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, typing.Union["CfnProject.DeviceTemplateProperty", _IResolvable_9ceae33e]]]]:
             """``CfnProject.PlacementTemplateProperty.DeviceTemplates``.
 
             see
@@ -712,9 +690,7 @@ class CfnProjectProps:
     def __init__(
         self,
         *,
-        placement_template: typing.Union[
-            "CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e
-        ],
+        placement_template: typing.Union["CfnProject.PlacementTemplateProperty", _IResolvable_9ceae33e],
         description: typing.Optional[str] = None,
         project_name: typing.Optional[str] = None,
     ) -> None:
