@@ -12,15 +12,15 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
+    Duration as _Duration_5170c158,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
     IResource as _IResource_72f7ee7e,
     Resource as _Resource_884d0774,
-    Duration as _Duration_5170c158,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_iam import Grant as _Grant_96af6d2d, IGrantable as _IGrantable_0fcfc53a
 from ..aws_kms import IKey as _IKey_3336c79d
@@ -48,9 +48,7 @@ class CfnStream(
         shard_count: jsii.Number,
         name: typing.Optional[str] = None,
         retention_period_hours: typing.Optional[jsii.Number] = None,
-        stream_encryption: typing.Optional[
-            typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]
-        ] = None,
+        stream_encryption: typing.Optional[typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::Kinesis::Stream``.
@@ -169,9 +167,7 @@ class CfnStream(
     @jsii.member(jsii_name="streamEncryption")
     def stream_encryption(
         self,
-    ) -> typing.Optional[
-        typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]]:
         """``AWS::Kinesis::Stream.StreamEncryption``.
 
         see
@@ -182,9 +178,7 @@ class CfnStream(
     @stream_encryption.setter
     def stream_encryption(
         self,
-        value: typing.Optional[
-            typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["StreamEncryptionProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "streamEncryption", value)
 
@@ -445,9 +439,7 @@ class CfnStreamProps:
         shard_count: jsii.Number,
         name: typing.Optional[str] = None,
         retention_period_hours: typing.Optional[jsii.Number] = None,
-        stream_encryption: typing.Optional[
-            typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]
-        ] = None,
+        stream_encryption: typing.Optional[typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Kinesis::Stream``.
@@ -503,9 +495,7 @@ class CfnStreamProps:
     @builtins.property
     def stream_encryption(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnStream.StreamEncryptionProperty", _IResolvable_9ceae33e]]:
         """``AWS::Kinesis::Stream.StreamEncryption``.
 
         see
@@ -912,7 +902,10 @@ class Stream(
 )
 class StreamAttributes:
     def __init__(
-        self, *, stream_arn: str, encryption_key: typing.Optional[_IKey_3336c79d] = None
+        self,
+        *,
+        stream_arn: str,
+        encryption_key: typing.Optional[_IKey_3336c79d] = None,
     ) -> None:
         """A reference to a stream.
 
