@@ -12,24 +12,24 @@ from .._jsii import *
 
 from .. import Duration as _Duration_5170c158
 from ..aws_apigateway import (
-    MethodOptions as _MethodOptions_0e815882,
     AuthorizationType as _AuthorizationType_2cb72e24,
     IAuthorizer as _IAuthorizer_fd7d6200,
-    MethodResponse as _MethodResponse_fdda6847,
     IModel as _IModel_13fecd8f,
     IRequestValidator as _IRequestValidator_f057dc3b,
+    MethodOptions as _MethodOptions_0e815882,
+    MethodResponse as _MethodResponse_fdda6847,
     RequestValidatorOptions as _RequestValidatorOptions_7a8ad269,
 )
 from ..aws_dynamodb import ITable as _ITable_e6850701
 from ..aws_kinesis import IStream as _IStream_c7ff3ed6
 from ..aws_lambda import (
-    IFunction as _IFunction_1c1de0bc,
-    IEventSource as _IEventSource_0e6bcb85,
-    StartingPosition as _StartingPosition_98f65751,
-    IEventSourceDlq as _IEventSourceDlq_64554172,
     DlqDestinationConfig as _DlqDestinationConfig_986227db,
-    IEventSourceMapping as _IEventSourceMapping_803047f8,
     EventSourceMappingOptions as _EventSourceMappingOptions_2fe36144,
+    IEventSource as _IEventSource_0e6bcb85,
+    IEventSourceDlq as _IEventSourceDlq_64554172,
+    IEventSourceMapping as _IEventSourceMapping_803047f8,
+    IFunction as _IFunction_1c1de0bc,
+    StartingPosition as _StartingPosition_98f65751,
 )
 from ..aws_s3 import (
     Bucket as _Bucket_abb659b1,
@@ -64,9 +64,7 @@ class ApiEventSource(
         request_models: typing.Optional[typing.Mapping[str, _IModel_13fecd8f]] = None,
         request_parameters: typing.Optional[typing.Mapping[str, bool]] = None,
         request_validator: typing.Optional[_IRequestValidator_f057dc3b] = None,
-        request_validator_options: typing.Optional[
-            _RequestValidatorOptions_7a8ad269
-        ] = None,
+        request_validator_options: typing.Optional[_RequestValidatorOptions_7a8ad269] = None,
     ) -> None:
         """
         :param method: -
