@@ -18,20 +18,19 @@ from ..aws_ec2 import (
     SubnetSelection as _SubnetSelection_36a13cd6,
 )
 from ..aws_iam import (
-    PolicyStatement as _PolicyStatement_f75dc775,
-    IRole as _IRole_e69bbae4,
+    IRole as _IRole_e69bbae4, PolicyStatement as _PolicyStatement_f75dc775
 )
 from ..aws_lambda import (
     AssetCode as _AssetCode_763678ad,
-    Runtime as _Runtime_8b970b80,
     Function as _Function_c537766c,
     FunctionOptions as _FunctionOptions_83fb7178,
     IDestination as _IDestination_7081f282,
-    VersionOptions as _VersionOptions_9a55a63d,
     IEventSource as _IEventSource_0e6bcb85,
     ILayerVersion as _ILayerVersion_aa5e0c0c,
     LogRetentionRetryOptions as _LogRetentionRetryOptions_09658088,
+    Runtime as _Runtime_8b970b80,
     Tracing as _Tracing_34f0a955,
+    VersionOptions as _VersionOptions_9a55a63d,
 )
 from ..aws_logs import RetentionDays as _RetentionDays_bdc7ad1f
 from ..aws_sqs import IQueue as _IQueue_b743f559
@@ -47,6 +46,10 @@ class Bundling(
     """
 
     def __init__(self) -> None:
+        """
+        stability
+        :stability: experimental
+        """
         jsii.create(Bundling, self, [])
 
     @jsii.member(jsii_name="parcel")
@@ -134,9 +137,7 @@ class NodejsFunction(
         initial_policy: typing.Optional[typing.List[_PolicyStatement_f75dc775]] = None,
         layers: typing.Optional[typing.List[_ILayerVersion_aa5e0c0c]] = None,
         log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
-        log_retention_retry_options: typing.Optional[
-            _LogRetentionRetryOptions_09658088
-        ] = None,
+        log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_09658088] = None,
         log_retention_role: typing.Optional[_IRole_e69bbae4] = None,
         memory_size: typing.Optional[jsii.Number] = None,
         profiling: typing.Optional[bool] = None,
@@ -777,9 +778,7 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         initial_policy: typing.Optional[typing.List[_PolicyStatement_f75dc775]] = None,
         layers: typing.Optional[typing.List[_ILayerVersion_aa5e0c0c]] = None,
         log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
-        log_retention_retry_options: typing.Optional[
-            _LogRetentionRetryOptions_09658088
-        ] = None,
+        log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_09658088] = None,
         log_retention_role: typing.Optional[_IRole_e69bbae4] = None,
         memory_size: typing.Optional[jsii.Number] = None,
         profiling: typing.Optional[bool] = None,
@@ -856,13 +855,9 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         :stability: experimental
         """
         if isinstance(current_version_options, dict):
-            current_version_options = _VersionOptions_9a55a63d(
-                **current_version_options
-            )
+            current_version_options = _VersionOptions_9a55a63d(**current_version_options)
         if isinstance(log_retention_retry_options, dict):
-            log_retention_retry_options = _LogRetentionRetryOptions_09658088(
-                **log_retention_retry_options
-            )
+            log_retention_retry_options = _LogRetentionRetryOptions_09658088(**log_retention_retry_options)
         if isinstance(vpc_subnets, dict):
             vpc_subnets = _SubnetSelection_36a13cd6(**vpc_subnets)
         self._values = {}
@@ -907,9 +902,7 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         if profiling_group is not None:
             self._values["profiling_group"] = profiling_group
         if reserved_concurrent_executions is not None:
-            self._values[
-                "reserved_concurrent_executions"
-            ] = reserved_concurrent_executions
+            self._values["reserved_concurrent_executions"] = reserved_concurrent_executions
         if role is not None:
             self._values["role"] = role
         if security_group is not None:
