@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    TreeInspector as _TreeInspector_154f5999,
-    IResolvable as _IResolvable_9ceae33e,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -352,9 +352,7 @@ class CfnFindingsFilter(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        finding_criteria: typing.Union[
-            "FindingCriteriaProperty", _IResolvable_9ceae33e
-        ],
+        finding_criteria: typing.Union["FindingCriteriaProperty", _IResolvable_9ceae33e],
         name: str,
         action: typing.Optional[str] = None,
         description: typing.Optional[str] = None,
@@ -545,11 +543,7 @@ class CfnFindingsFilter(
         def __init__(
             self,
             *,
-            criterion: typing.Optional[
-                typing.Union[
-                    "CfnFindingsFilter.CriterionProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            criterion: typing.Optional[typing.Union["CfnFindingsFilter.CriterionProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param criterion: ``CfnFindingsFilter.FindingCriteriaProperty.Criterion``.
@@ -564,9 +558,7 @@ class CfnFindingsFilter(
         @builtins.property
         def criterion(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnFindingsFilter.CriterionProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnFindingsFilter.CriterionProperty", _IResolvable_9ceae33e]]:
             """``CfnFindingsFilter.FindingCriteriaProperty.Criterion``.
 
             see
@@ -601,9 +593,7 @@ class CfnFindingsFilterProps:
     def __init__(
         self,
         *,
-        finding_criteria: typing.Union[
-            "CfnFindingsFilter.FindingCriteriaProperty", _IResolvable_9ceae33e
-        ],
+        finding_criteria: typing.Union["CfnFindingsFilter.FindingCriteriaProperty", _IResolvable_9ceae33e],
         name: str,
         action: typing.Optional[str] = None,
         description: typing.Optional[str] = None,
@@ -634,9 +624,7 @@ class CfnFindingsFilterProps:
     @builtins.property
     def finding_criteria(
         self,
-    ) -> typing.Union[
-        "CfnFindingsFilter.FindingCriteriaProperty", _IResolvable_9ceae33e
-    ]:
+    ) -> typing.Union["CfnFindingsFilter.FindingCriteriaProperty", _IResolvable_9ceae33e]:
         """``AWS::Macie::FindingsFilter.FindingCriteria``.
 
         see
