@@ -13,10 +13,10 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
     IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -333,13 +333,8 @@ class CfnRobotApplication(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        robot_software_suite: typing.Union[
-            "RobotSoftwareSuiteProperty", _IResolvable_9ceae33e
-        ],
-        sources: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]],
-        ],
+        robot_software_suite: typing.Union["RobotSoftwareSuiteProperty", _IResolvable_9ceae33e],
+        sources: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]]],
         current_revision_id: typing.Optional[str] = None,
         name: typing.Optional[str] = None,
         tags: typing.Any = None,
@@ -445,10 +440,7 @@ class CfnRobotApplication(
     @jsii.member(jsii_name="sources")
     def sources(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]]]:
         """``AWS::RoboMaker::RobotApplication.Sources``.
 
         see
@@ -459,10 +451,7 @@ class CfnRobotApplication(
     @sources.setter
     def sources(
         self,
-        value: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]],
-        ],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "sources", value)
 
@@ -621,17 +610,8 @@ class CfnRobotApplicationProps:
     def __init__(
         self,
         *,
-        robot_software_suite: typing.Union[
-            "CfnRobotApplication.RobotSoftwareSuiteProperty", _IResolvable_9ceae33e
-        ],
-        sources: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnRobotApplication.SourceConfigProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ],
+        robot_software_suite: typing.Union["CfnRobotApplication.RobotSoftwareSuiteProperty", _IResolvable_9ceae33e],
+        sources: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnRobotApplication.SourceConfigProperty", _IResolvable_9ceae33e]]],
         current_revision_id: typing.Optional[str] = None,
         name: typing.Optional[str] = None,
         tags: typing.Any = None,
@@ -661,9 +641,7 @@ class CfnRobotApplicationProps:
     @builtins.property
     def robot_software_suite(
         self,
-    ) -> typing.Union[
-        "CfnRobotApplication.RobotSoftwareSuiteProperty", _IResolvable_9ceae33e
-    ]:
+    ) -> typing.Union["CfnRobotApplication.RobotSoftwareSuiteProperty", _IResolvable_9ceae33e]:
         """``AWS::RoboMaker::RobotApplication.RobotSoftwareSuite``.
 
         see
@@ -674,14 +652,7 @@ class CfnRobotApplicationProps:
     @builtins.property
     def sources(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[
-            typing.Union[
-                "CfnRobotApplication.SourceConfigProperty", _IResolvable_9ceae33e
-            ]
-        ],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnRobotApplication.SourceConfigProperty", _IResolvable_9ceae33e]]]:
         """``AWS::RoboMaker::RobotApplication.Sources``.
 
         see
@@ -998,19 +969,10 @@ class CfnSimulationApplication(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        rendering_engine: typing.Union[
-            "RenderingEngineProperty", _IResolvable_9ceae33e
-        ],
-        robot_software_suite: typing.Union[
-            "RobotSoftwareSuiteProperty", _IResolvable_9ceae33e
-        ],
-        simulation_software_suite: typing.Union[
-            "SimulationSoftwareSuiteProperty", _IResolvable_9ceae33e
-        ],
-        sources: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]],
-        ],
+        rendering_engine: typing.Union["RenderingEngineProperty", _IResolvable_9ceae33e],
+        robot_software_suite: typing.Union["RobotSoftwareSuiteProperty", _IResolvable_9ceae33e],
+        simulation_software_suite: typing.Union["SimulationSoftwareSuiteProperty", _IResolvable_9ceae33e],
+        sources: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]]],
         current_revision_id: typing.Optional[str] = None,
         name: typing.Optional[str] = None,
         tags: typing.Any = None,
@@ -1157,10 +1119,7 @@ class CfnSimulationApplication(
     @jsii.member(jsii_name="sources")
     def sources(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]]]:
         """``AWS::RoboMaker::SimulationApplication.Sources``.
 
         see
@@ -1171,10 +1130,7 @@ class CfnSimulationApplication(
     @sources.setter
     def sources(
         self,
-        value: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]],
-        ],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SourceConfigProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "sources", value)
 
@@ -1431,25 +1387,10 @@ class CfnSimulationApplicationProps:
     def __init__(
         self,
         *,
-        rendering_engine: typing.Union[
-            "CfnSimulationApplication.RenderingEngineProperty", _IResolvable_9ceae33e
-        ],
-        robot_software_suite: typing.Union[
-            "CfnSimulationApplication.RobotSoftwareSuiteProperty", _IResolvable_9ceae33e
-        ],
-        simulation_software_suite: typing.Union[
-            "CfnSimulationApplication.SimulationSoftwareSuiteProperty",
-            _IResolvable_9ceae33e,
-        ],
-        sources: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnSimulationApplication.SourceConfigProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ],
-        ],
+        rendering_engine: typing.Union["CfnSimulationApplication.RenderingEngineProperty", _IResolvable_9ceae33e],
+        robot_software_suite: typing.Union["CfnSimulationApplication.RobotSoftwareSuiteProperty", _IResolvable_9ceae33e],
+        simulation_software_suite: typing.Union["CfnSimulationApplication.SimulationSoftwareSuiteProperty", _IResolvable_9ceae33e],
+        sources: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnSimulationApplication.SourceConfigProperty", _IResolvable_9ceae33e]]],
         current_revision_id: typing.Optional[str] = None,
         name: typing.Optional[str] = None,
         tags: typing.Any = None,
@@ -1483,9 +1424,7 @@ class CfnSimulationApplicationProps:
     @builtins.property
     def rendering_engine(
         self,
-    ) -> typing.Union[
-        "CfnSimulationApplication.RenderingEngineProperty", _IResolvable_9ceae33e
-    ]:
+    ) -> typing.Union["CfnSimulationApplication.RenderingEngineProperty", _IResolvable_9ceae33e]:
         """``AWS::RoboMaker::SimulationApplication.RenderingEngine``.
 
         see
@@ -1496,9 +1435,7 @@ class CfnSimulationApplicationProps:
     @builtins.property
     def robot_software_suite(
         self,
-    ) -> typing.Union[
-        "CfnSimulationApplication.RobotSoftwareSuiteProperty", _IResolvable_9ceae33e
-    ]:
+    ) -> typing.Union["CfnSimulationApplication.RobotSoftwareSuiteProperty", _IResolvable_9ceae33e]:
         """``AWS::RoboMaker::SimulationApplication.RobotSoftwareSuite``.
 
         see
@@ -1509,10 +1446,7 @@ class CfnSimulationApplicationProps:
     @builtins.property
     def simulation_software_suite(
         self,
-    ) -> typing.Union[
-        "CfnSimulationApplication.SimulationSoftwareSuiteProperty",
-        _IResolvable_9ceae33e,
-    ]:
+    ) -> typing.Union["CfnSimulationApplication.SimulationSoftwareSuiteProperty", _IResolvable_9ceae33e]:
         """``AWS::RoboMaker::SimulationApplication.SimulationSoftwareSuite``.
 
         see
@@ -1523,14 +1457,7 @@ class CfnSimulationApplicationProps:
     @builtins.property
     def sources(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[
-            typing.Union[
-                "CfnSimulationApplication.SourceConfigProperty", _IResolvable_9ceae33e
-            ]
-        ],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnSimulationApplication.SourceConfigProperty", _IResolvable_9ceae33e]]]:
         """``AWS::RoboMaker::SimulationApplication.Sources``.
 
         see
