@@ -10,9 +10,15 @@ import publication
 
 from .._jsii import *
 
-from .. import Construct as _Construct_f50a3f53, Duration as _Duration_5170c158
+from .. import (
+    AssetHashType as _AssetHashType_16f7047a,
+    BundlingOptions as _BundlingOptions_0cab5223,
+    Construct as _Construct_f50a3f53,
+    Duration as _Duration_5170c158,
+)
+from ..assets import FollowMode as _FollowMode_f74e7125
 from ..aws_cloudfront import IDistribution as _IDistribution_0af1f2d0
-from ..aws_iam import IRole as _IRole_e69bbae4, IGrantable as _IGrantable_0fcfc53a
+from ..aws_iam import IGrantable as _IGrantable_0fcfc53a, IRole as _IRole_e69bbae4
 from ..aws_s3 import IBucket as _IBucket_25bad983
 from ..aws_s3_assets import AssetOptions as _AssetOptions_ed6c2956
 
@@ -225,13 +231,9 @@ class BucketDeploymentProps:
         if server_side_encryption is not None:
             self._values["server_side_encryption"] = server_side_encryption
         if server_side_encryption_aws_kms_key_id is not None:
-            self._values[
-                "server_side_encryption_aws_kms_key_id"
-            ] = server_side_encryption_aws_kms_key_id
+            self._values["server_side_encryption_aws_kms_key_id"] = server_side_encryption_aws_kms_key_id
         if server_side_encryption_customer_algorithm is not None:
-            self._values[
-                "server_side_encryption_customer_algorithm"
-            ] = server_side_encryption_customer_algorithm
+            self._values["server_side_encryption_customer_algorithm"] = server_side_encryption_customer_algorithm
         if storage_class is not None:
             self._values["storage_class"] = storage_class
         if website_redirect_location is not None:
