@@ -11,19 +11,23 @@ import publication
 from .._jsii import *
 
 from .. import (
-    Construct as _Construct_f50a3f53,
-    Resource as _Resource_884d0774,
-    Duration as _Duration_5170c158,
+    AssetHashType as _AssetHashType_16f7047a,
+    BundlingOptions as _BundlingOptions_0cab5223,
     CfnResource as _CfnResource_7760e8e4,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
+    Duration as _Duration_5170c158,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    Resource as _Resource_884d0774,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
+from ..assets import FollowMode as _FollowMode_f74e7125
 from ..aws_cloudwatch import (
     Metric as _Metric_53e89548,
     MetricOptions as _MetricOptions_ad2c4d5d,
+    Unit as _Unit_e1b74f3c,
 )
 from ..aws_iam import IGrantable as _IGrantable_0fcfc53a, IRole as _IRole_e69bbae4
 from ..aws_s3 import IBucket as _IBucket_25bad983, Location as _Location_2d2ff215
@@ -386,9 +390,7 @@ class CanaryProps:
         :stability: experimental
         """
         if isinstance(artifacts_bucket_location, dict):
-            artifacts_bucket_location = ArtifactsBucketLocation(
-                **artifacts_bucket_location
-            )
+            artifacts_bucket_location = ArtifactsBucketLocation(**artifacts_bucket_location)
         self._values = {
             "test": test,
         }
@@ -597,14 +599,10 @@ class CfnCanary(
         schedule: typing.Union["ScheduleProperty", _IResolvable_9ceae33e],
         start_canary_after_creation: typing.Union[bool, _IResolvable_9ceae33e],
         failure_retention_period: typing.Optional[jsii.Number] = None,
-        run_config: typing.Optional[
-            typing.Union["RunConfigProperty", _IResolvable_9ceae33e]
-        ] = None,
+        run_config: typing.Optional[typing.Union["RunConfigProperty", _IResolvable_9ceae33e]] = None,
         success_retention_period: typing.Optional[jsii.Number] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        vpc_config: typing.Optional[
-            typing.Union["VPCConfigProperty", _IResolvable_9ceae33e]
-        ] = None,
+        vpc_config: typing.Optional[typing.Union["VPCConfigProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Create a new ``AWS::Synthetics::Canary``.
 
@@ -830,9 +828,7 @@ class CfnCanary(
     @run_config.setter
     def run_config(
         self,
-        value: typing.Optional[
-            typing.Union["RunConfigProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["RunConfigProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "runConfig", value)
 
@@ -865,9 +861,7 @@ class CfnCanary(
     @vpc_config.setter
     def vpc_config(
         self,
-        value: typing.Optional[
-            typing.Union["VPCConfigProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["VPCConfigProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "vpcConfig", value)
 
@@ -1182,14 +1176,10 @@ class CfnCanaryProps:
         schedule: typing.Union["CfnCanary.ScheduleProperty", _IResolvable_9ceae33e],
         start_canary_after_creation: typing.Union[bool, _IResolvable_9ceae33e],
         failure_retention_period: typing.Optional[jsii.Number] = None,
-        run_config: typing.Optional[
-            typing.Union["CfnCanary.RunConfigProperty", _IResolvable_9ceae33e]
-        ] = None,
+        run_config: typing.Optional[typing.Union["CfnCanary.RunConfigProperty", _IResolvable_9ceae33e]] = None,
         success_retention_period: typing.Optional[jsii.Number] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        vpc_config: typing.Optional[
-            typing.Union["CfnCanary.VPCConfigProperty", _IResolvable_9ceae33e]
-        ] = None,
+        vpc_config: typing.Optional[typing.Union["CfnCanary.VPCConfigProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Synthetics::Canary``.
 
@@ -1306,9 +1296,7 @@ class CfnCanaryProps:
     @builtins.property
     def run_config(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnCanary.RunConfigProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnCanary.RunConfigProperty", _IResolvable_9ceae33e]]:
         """``AWS::Synthetics::Canary.RunConfig``.
 
         see
@@ -1337,9 +1325,7 @@ class CfnCanaryProps:
     @builtins.property
     def vpc_config(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnCanary.VPCConfigProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnCanary.VPCConfigProperty", _IResolvable_9ceae33e]]:
         """``AWS::Synthetics::Canary.VPCConfig``.
 
         see
@@ -1360,7 +1346,8 @@ class CfnCanaryProps:
 
 
 class Code(
-    metaclass=jsii.JSIIAbstractClass, jsii_type="monocdk-experiment.aws_synthetics.Code"
+    metaclass=jsii.JSIIAbstractClass,
+    jsii_type="monocdk-experiment.aws_synthetics.Code",
 ):
     """The code the canary should execute.
 
@@ -1373,6 +1360,10 @@ class Code(
         return _CodeProxy
 
     def __init__(self) -> None:
+        """
+        stability
+        :stability: experimental
+        """
         jsii.create(Code, self, [])
 
     @jsii.member(jsii_name="fromAsset")
