@@ -117,17 +117,8 @@ class ArtifactManifest:
         type: "ArtifactType",
         dependencies: typing.Optional[typing.List[str]] = None,
         environment: typing.Optional[str] = None,
-        metadata: typing.Optional[
-            typing.Mapping[str, typing.List["MetadataEntry"]]
-        ] = None,
-        properties: typing.Optional[
-            typing.Union[
-                "AwsCloudFormationStackProperties",
-                "AssetManifestProperties",
-                "TreeArtifactProperties",
-                "NestedCloudAssemblyProperties",
-            ]
-        ] = None,
+        metadata: typing.Optional[typing.Mapping[str, typing.List["MetadataEntry"]]] = None,
+        properties: typing.Optional[typing.Union["AwsCloudFormationStackProperties", "AssetManifestProperties", "TreeArtifactProperties", "NestedCloudAssemblyProperties"]] = None,
     ) -> None:
         """A manifest for a single artifact within the cloud assembly.
 
@@ -202,14 +193,7 @@ class ArtifactManifest:
     @builtins.property
     def properties(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "AwsCloudFormationStackProperties",
-            "AssetManifestProperties",
-            "TreeArtifactProperties",
-            "NestedCloudAssemblyProperties",
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["AwsCloudFormationStackProperties", "AssetManifestProperties", "TreeArtifactProperties", "NestedCloudAssemblyProperties"]]:
         """The set of properties for this artifact (depends on type).
 
         default
@@ -527,9 +511,7 @@ class AssetManifestProperties:
             "file": file,
         }
         if requires_bootstrap_stack_version is not None:
-            self._values[
-                "requires_bootstrap_stack_version"
-            ] = requires_bootstrap_stack_version
+            self._values["requires_bootstrap_stack_version"] = requires_bootstrap_stack_version
 
     @builtins.property
     def file(self) -> str:
@@ -661,21 +643,15 @@ class AwsCloudFormationStackProperties:
         if assume_role_arn is not None:
             self._values["assume_role_arn"] = assume_role_arn
         if cloud_formation_execution_role_arn is not None:
-            self._values[
-                "cloud_formation_execution_role_arn"
-            ] = cloud_formation_execution_role_arn
+            self._values["cloud_formation_execution_role_arn"] = cloud_formation_execution_role_arn
         if parameters is not None:
             self._values["parameters"] = parameters
         if requires_bootstrap_stack_version is not None:
-            self._values[
-                "requires_bootstrap_stack_version"
-            ] = requires_bootstrap_stack_version
+            self._values["requires_bootstrap_stack_version"] = requires_bootstrap_stack_version
         if stack_name is not None:
             self._values["stack_name"] = stack_name
         if stack_template_asset_object_url is not None:
-            self._values[
-                "stack_template_asset_object_url"
-            ] = stack_template_asset_object_url
+            self._values["stack_template_asset_object_url"] = stack_template_asset_object_url
         if termination_protection is not None:
             self._values["termination_protection"] = termination_protection
 
@@ -1108,9 +1084,7 @@ class ContextProvider(enum.Enum):
     stability
     :stability: experimental
     """
-    ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER = (
-        "ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER"
-    )
+    ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER = "ENDPOINT_SERVICE_AVAILABILITY_ZONE_PROVIDER"
     """VPC Endpoint Service AZ Provider.
 
     stability
@@ -2038,14 +2012,7 @@ class MetadataEntry:
         self,
         *,
         type: str,
-        data: typing.Optional[
-            typing.Union[
-                str,
-                "FileAssetMetadataEntry",
-                "ContainerImageAssetMetadataEntry",
-                typing.List["Tag"],
-            ]
-        ] = None,
+        data: typing.Optional[typing.Union[str, "FileAssetMetadataEntry", "ContainerImageAssetMetadataEntry", typing.List["Tag"]]] = None,
         trace: typing.Optional[typing.List[str]] = None,
     ) -> None:
         """A metadata entry in a cloud assembly artifact.
@@ -2077,14 +2044,7 @@ class MetadataEntry:
     @builtins.property
     def data(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            str,
-            "FileAssetMetadataEntry",
-            "ContainerImageAssetMetadataEntry",
-            typing.List["Tag"],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[str, "FileAssetMetadataEntry", "ContainerImageAssetMetadataEntry", typing.List["Tag"]]]:
         """The data.
 
         default
@@ -2129,14 +2089,7 @@ class MissingContext:
         self,
         *,
         key: str,
-        props: typing.Union[
-            "AmiContextQuery",
-            "AvailabilityZonesContextQuery",
-            "HostedZoneContextQuery",
-            "SSMParameterContextQuery",
-            "VpcContextQuery",
-            "EndpointServiceAvailabilityZonesContextQuery",
-        ],
+        props: typing.Union["AmiContextQuery", "AvailabilityZonesContextQuery", "HostedZoneContextQuery", "SSMParameterContextQuery", "VpcContextQuery", "EndpointServiceAvailabilityZonesContextQuery"],
         provider: "ContextProvider",
     ) -> None:
         """Represents a missing piece of context.
@@ -2166,14 +2119,7 @@ class MissingContext:
     @builtins.property
     def props(
         self,
-    ) -> typing.Union[
-        "AmiContextQuery",
-        "AvailabilityZonesContextQuery",
-        "HostedZoneContextQuery",
-        "SSMParameterContextQuery",
-        "VpcContextQuery",
-        "EndpointServiceAvailabilityZonesContextQuery",
-    ]:
+    ) -> typing.Union["AmiContextQuery", "AvailabilityZonesContextQuery", "HostedZoneContextQuery", "SSMParameterContextQuery", "VpcContextQuery", "EndpointServiceAvailabilityZonesContextQuery"]:
         """A set of provider-specific options.
 
         stability
@@ -2407,7 +2353,9 @@ class Tag:
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return "Tag(%s)" % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
+        return "Tag(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.data_type(
